@@ -79,7 +79,7 @@
 ///////////////////////////////////////////////
 extern char gHomeDir[PATH_MAX];     // ~/.mfiler3/のパス
 extern char gTempDir[PATH_MAX];     // 一時ディレクトリのパス
-extern BOOL gMainLoop;              // メインループを回すかどうか
+extern int gMainLoop;               // メインループを回すかどうか -1の間回す。終了時はリターンコードとなる
 extern BOOL gExitCode;              // 終了コード
 
 extern void (*gView)();             // 登録描写関数(関数を登録しておけばviewで実行される)
