@@ -27,15 +27,20 @@ void merr_msg(char* msg, ...)
         const int maxy = mgetmaxy();
         const int maxx = mgetmaxx();
 
-        mclear();
-        view(TRUE);
-        mclear_online(maxy-2);
-        mclear_online(maxy-1);
-        mmvprintw(maxy-2, 0, "%s", msg2);
-        mrefresh();
+        if(mis_raw_mode()) {
+            mclear();
+            view(TRUE);
+            mclear_online(maxy-2);
+            mclear_online(maxy-1);
+            mmvprintw(maxy-2, 0, "%s", msg2);
+            mrefresh();
 
-        int meta;
-        mgetch(&meta);
+            int meta;
+            mgetch(&meta);
+        }
+        else {
+            fprintf(stderr, "%s", msg2);
+        }
     }
     else {
         char msg2[1024];
